# ExchangeRateAPI

A Python wrapper for the Exchange Rates API.

## Installation

```bash
pip install ExchangeRateAPI
```

## Usage

```python
from pyxr import ExchangeRateAPI

api = ExchangeRateAPI(access_key="your_access_key")
print(api.get_latest())
```

## License

To create...
